package com.ruoyi.borrow.service;

import java.util.List;
import com.ruoyi.borrow.domain.TbAssetBorrowRecord;

/**
 * 资产借用Service接口
 * 
 * @author ruoyi
 * @date 2024-01-11
 */
public interface ITbAssetBorrowRecordService
{
    /**
     * 快速归还
     *
     * @param assetNumber 资产编码
     * @return null/错误消息
     */
    public String fastReturnByAssetNumber(String assetNumber);

    /**
     * 查询资产借用
     * 
     * @param id 资产借用主键
     * @return 资产借用
     */
    public TbAssetBorrowRecord selectTbAssetBorrowRecordById(Long id);

    /**
     * 查询资产借用列表
     * 
     * @param tbAssetBorrowRecord 资产借用
     * @return 资产借用集合
     */
    public List<TbAssetBorrowRecord> selectTbAssetBorrowRecordList(TbAssetBorrowRecord tbAssetBorrowRecord);

    /**
     * 新增资产借用
     * 
     * @param tbAssetBorrowRecord 资产借用
     * @return 结果
     */
    public int insertTbAssetBorrowRecord(TbAssetBorrowRecord tbAssetBorrowRecord);

    /**
     * 修改资产借用
     * 
     * @param tbAssetBorrowRecord 资产借用
     * @return 结果
     */
    public int updateTbAssetBorrowRecord(TbAssetBorrowRecord tbAssetBorrowRecord);

    /**
     * 批量删除资产借用
     * 
     * @param ids 需要删除的资产借用主键集合
     * @return 结果
     */
    public int deleteTbAssetBorrowRecordByIds(Long[] ids);

    /**
     * 删除资产借用信息
     * 
     * @param id 资产借用主键
     * @return 结果
     */
    public int deleteTbAssetBorrowRecordById(Long id);
}
